@@ -10,7 +10,7 @@ use warnings;
 use Carp;
 
 use vars qw/$VERSION/;
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use Acme::Chef::Recipe;
 use Acme::Chef::Container;
@@ -398,7 +398,7 @@ method instructions are:
 
 =item *
 
-C<Take ingredient from refridgerator.>
+C<Take ingredient from refrigerator.>
 
 I<New specification!> This reads lines from STDIN until a
 numerical value is found. This numerical value is put into the
@@ -604,9 +604,9 @@ Steffen Mueller.
 
 Chef was designed by David Morgan-Mar.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2005 Steffen Mueller. All rights reserved. This program is
+Copyright (c) 2002-2008 Steffen Mueller. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
