@@ -67,7 +67,7 @@ $VERSION = '1.00';
      take_from => sub {
         my $recipe = shift;
         local $_ = shift;
-        /^Take $ingr from refridgerator$/ or return();
+        /^Take $ingr from refrigerator$/ or return();
         $recipe->require_ingredient($1);
         return 'take_from', $1;
      },
@@ -809,9 +809,9 @@ Steffen Mueller.
 
 Chef designed by David Morgan-Mar.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2005 Steffen Mueller. All rights reserved. This program is
+Copyright (c) 2002-2008 Steffen Mueller. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
